@@ -1,16 +1,17 @@
 #' Read in SIBER format data and generate the SIBER object
-#' 
-#' This function takes raw isotope data and creates a SIBER object which 
-#' contains information in a structured manner that enables other functions to 
-#' loop over groups and communities, fit Bayesian ellipses, and afterwards, 
-#' generate various plots, and additional analyses on the posterior 
+#'
+#' This function takes raw isotope data and creates a SIBER object which
+#' contains information in a structured manner that enables other functions to
+#' loop over groups and communities, fit Bayesian ellipses, and afterwards,
+#' generate various plots, and additional analyses on the posterior
 #' distributions.
 #' 
-#' @param data.in Specified In a basic R data.frame or matrix comprising 4 
-#'   columns. The first two of which are typically isotope tracers, then the 
-#'   third is a column that indicates the group membership, and the fourth 
-#'   column indicates the community membership of an observation. Communities 
-#'   labels should be entered  as sequential numbers. As of v2.0.1 group labels 
+#' @name createSiberObject
+#' @param data.in Specified In a basic R data.frame or matrix comprising 4
+#'   columns. The first two of which are typically isotope tracers, then the
+#'   third is a column that indicates the group membership, and the fourth
+#'   column indicates the community membership of an observation. Communities
+#'   labels should be entered  as sequential numbers. As of v2.0.1 group labels
 #'   can be entered as strings and/or numbers and need not be sequential.
 #' @return A siber list object, that contains data that helps with various model
 #'   fitting and plotting. \itemize{ \item {original.data}{The original data as
@@ -22,9 +23,16 @@
 #' data(demo.siber.data)
 #' my.siber.data <- createSiberObject(demo.siber.data)
 #' names(my.siber.data)
-#' 
+#'
 #' @export
 
+## Define a set of global variables so tidyverse calles dont generate
+# "no visible binding for global variable" warnings.
+if(getRversion() >= "2.15.1")  utils::globalVariables(c("iso1", 
+                                                        "iso2",
+                                                        "group", 
+                                                        "community"))
+
 createSiberObject <- function (data.in) {
 
 # Check that the column headers have exactly the correct string
@@ -162,15 +170,40 @@ names(siber$ML.cov) <- siber$all.communities
 siber$zscore.data <-  siber$raw.data
 
 for (i in 1:siber$n.communities) {
-
+  
+  # BUG - discovered 2020/5/11 per emails with Edward Doherty.
+  # Incorrect ordering by tapply() meant z-scores were not correctly
+  # applied within groups.
+  
+  
+  # -- BUGGED CODE BEGIN --
   # apply z-score transform to each group within the community via tapply()
   # using the function scale()
-  siber$zscore.data[[i]][,1] <- unlist(tapply(siber$raw.data[[i]]$iso1, 
-  	                                          siber$raw.data[[i]]$group,
-  	                                          scale))
-  siber$zscore.data[[i]][,2] <- unlist(tapply(siber$raw.data[[i]]$iso2, 
-  	                                          siber$raw.data[[i]]$group, 
-  	                                          scale))
+  # siber$zscore.data[[i]][,1] <- unlist(tapply(siber$raw.data[[i]]$iso1,
+  # 	                                          siber$raw.data[[i]]$group,
+  # 	                                          scale))
+  # siber$zscore.data[[i]][,2] <- unlist(tapply(siber$raw.data[[i]]$iso2,
+  # 	                                          siber$raw.data[[i]]$group,
+  # 	                                          scale))
+  # 
+  # -- BUGGED CODE END --
+  
+  
+  
+  
+  
+  ## -- HOT FIX BEGIN -- 
+  # (plan to tidyverse the whole package)
+  
+  # take the raw data, group by "group" and 
+  # transform iso1 and iso2 by scaling them and
+  # finally converting to data.frame.
+  siber$zscore.data[[i]] <- siber$raw.data[[i]] %>%
+    group_by(group) %>% mutate(iso1 = scale(iso1),
+                               iso2 = scale(iso2)) %>%
+    data.frame()
+  # 
+  ## -- HOT FIX END   --
 
 	
 }
